DeviceAuthKeyError

Enum DeviceAuthKeyError 

pub enum DeviceAuthKeyError {
Show 19 variants AuthenticatorFailure, Conversion, CredentialExcluded, InvalidRecordIdentifier, InvalidWebVaultUrl, MissingDeviceAuthKey, UnregisterFailure, InvalidCoseKey, InvalidPublicKeyCredentialDescriptor, MasterPasswordHash, MissingCredentialId, MissingHmacSecret, MissingUserHandle, NotImplemented, RetrieveRegistrationOptionsFailure, PrfFailure, SubmitRegistrationFailure, UserCancelled, Unknown { reason: String, },
}
Errors related to processing the device auth key.

Variants



AuthenticatorFailure

Authenticator failed to produce a valid response.



Conversion

Failed to convert between Rust types.



CredentialExcluded

Credential excluded.



InvalidRecordIdentifier

The record identifier stored in metadata is not a valid UUID.



InvalidWebVaultUrl

Invalid Web Vault URL specified.



MissingDeviceAuthKey

No device auth key exists on this device.



UnregisterFailure

Failed to unregister device auth key from server.



InvalidCoseKey

Failed to de-/serialize COSE key data.



InvalidPublicKeyCredentialDescriptor

An invalid public key credential descriptor was passed in the allow list.



MasterPasswordHash

A master password hash could not be generated for the given master password.



MissingCredentialId

Credential ID was not returned in the response and was not passed in the request.



MissingHmacSecret

No HMAC secret was returned with the credential.



MissingUserHandle

User handle was not returned in the response.



NotImplemented

Feature is not yet implemented.



RetrieveRegistrationOptionsFailure

Failed to retrieve the registration options from the server.



PrfFailure

Failed to generate rotateable key set from PRF output.



SubmitRegistrationFailure

Failed to submit registration request to the server.



UserCancelled

User cancelled the operation.



Unknown

An unknown error occurred.

Fields

reason: String

Reason for the error.