Enum UiHint
pub enum UiHint<'a, P> {
InformExcludedCredentialFound(&'a P),
InformNoCredentialsFound,
RequestNewCredential(&'a PublicKeyCredentialUserEntity, &'a PublicKeyCredentialRpEntity),
RequestExistingCredential(&'a P),
}Expand description
Additional information that can be displayed to the user if the authenticator has a display.
Variants
InformExcludedCredentialFound(&'a P)
Inform the user that the operation cannot be completed because the user already has a credential registered.
InformNoCredentialsFound
Inform the user that the operation cannot be completed because the user has no matching credentials registered.
RequestNewCredential(&'a PublicKeyCredentialUserEntity, &'a PublicKeyCredentialRpEntity)
Request permission to save the credential in this object.
RequestExistingCredential(&'a P)
Request permission to use the existing credential in this object.