pub struct DeviceAuthKeyMetadata {
pub record_identifier: String,
pub creation_date: DateTime<Utc>,
pub credential_id: Vec<u8>,
pub rp_id: String,
pub user_name: String,
pub user_handle: Vec<u8>,
pub user_display_name: String,
}Expand description
The metadata for the device auth key useful for looking up whether the authenticator can satisfy a given request before invoking user-verifying access control.
Fields
record_identifier: StringA unique identifier for the device auth key passkey. This can be used as a unique identifier in OS autofill stores.
creation_date: DateTime<Utc>Date the device auth key was created.
credential_id: Vec<u8>FIDO credential ID for the device auth key.
rp_id: StringWebAuthn RP ID for the device auth key.
user_name: StringThe login or username for user.
Corresponds to the [user.name] in the original WebAuthn request that created the credential.
user_handle: Vec<u8>The ID for the user.
Corresponds to the [user.id] in the original WebAuthn request that created the credential.
user_display_name: StringThe display name for the user
Corresponds to the [user.displayName] in the original WebAuthn request that created the credential.