pub struct DeviceAuthKeyRecord {
pub credential_id: Vec<u8>,
pub key: Vec<u8>,
pub rp_id: String,
pub user_id: Vec<u8>,
pub counter: Option<u32>,
pub hmac_secret: Vec<u8>,
}Expand description
The private key material for the device auth key. This should be stored separately from the metadata and gated behind user-verifying access control.
Fields
credential_id: Vec<u8>Credential ID for the WebAuthn credential.
key: Vec<u8>Private key material, formatted as a COSE key.
rp_id: StringRP ID of the WebAuthn credential.
user_id: Vec<u8>User ID for the WebAuthn credential.
counter: Option<u32>WebAuthn counter for the credential.
hmac_secret: Vec<u8>HMAC Secret seed, which can also be used in WebAuthn PRF extension.