pub struct DeviceAuthKeyAuthenticator<'a> {
pub client: &'a Client,
pub store: &'a mut dyn DeviceAuthKeyStore,
}Expand description
A FIDO authenticator that uses the device auth key for its key material.
Fields
client: &'a ClientThe SDK client.
store: &'a mut dyn DeviceAuthKeyStoreCallbacks for storing and retrieving the device auth key during FIDO operations.
Implementations
Sourceimpl DeviceAuthKeyAuthenticator<'_>
impl DeviceAuthKeyAuthenticator<'_>
Sourcepub async fn create_device_auth_key(
&mut self,
client_name: String,
web_vault_url: String,
email: String,
secret_verification_request: SecretVerificationRequest,
kdf_params: Kdf,
) -> Result<(), DeviceAuthKeyError>
pub async fn create_device_auth_key( &mut self, client_name: String, web_vault_url: String, email: String, secret_verification_request: SecretVerificationRequest, kdf_params: Kdf, ) -> Result<(), DeviceAuthKeyError>
Create a device auth key by registering an unlock passkey and PRF keyset with the server. The passkey private key and metadata will be stored on the device using the provided trait implementation.
Sourcepub async fn assert_device_auth_key(
&mut self,
request: GetAssertionRequest,
) -> Result<DeviceAuthKeyGetAssertionResult, DeviceAuthKeyError>
pub async fn assert_device_auth_key( &mut self, request: GetAssertionRequest, ) -> Result<DeviceAuthKeyGetAssertionResult, DeviceAuthKeyError>
Satisfy the given FIDO assertion request using the device auth key.
The device auth key will be looked up from the
DeviceAuthKeyAuthenticator::store provided in the initializer.
Sourcepub async fn unregister_device_auth_key(
&mut self,
email: String,
secret_verification_request: SecretVerificationRequest,
kdf_params: Kdf,
) -> Result<(), DeviceAuthKeyError>
pub async fn unregister_device_auth_key( &mut self, email: String, secret_verification_request: SecretVerificationRequest, kdf_params: Kdf, ) -> Result<(), DeviceAuthKeyError>
Delete the device auth key from the device and unregister it from the server.